function [strategy,bet] = setStrategy(type,HLI);
% type 'basic': basic strategy
% type 'thorp': Complete Point-Count system (needs HLI)
%
% strategy: bet, PAIR, SOFT, HARD

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Blackjack Markov Chain Toolbox, v1.0 (08 Jan 2009)
%%% 
%%% Companion to manuscript 
%%%    "A Markov Chain Analysis of Blackjack Strategy"
%%%    by Michael B. Wakin and Christopher J. Rozell, 2004.
%%%    available at: http://inside.mines.edu/~mwakin/papers/mcbj.pdf
%%%
%%% Software Copyright 2009 by 
%%%    Michael B. Wakin, Colorado School of Mines, mwakin@mines.edu
%%%    Christopher J. Rozell, Georgia Tech, crozell@gatech.edu 
%%%
%%% This software is released under a Creative Commons license
%%% (Attribution 3.0 Unported): 
%%%     http://creativecommons.org/licenses/by/3.0/
%%% You are free:
%%%    * to Share  to copy, distribute and transmit the work
%%%    * to Remix  to adapt the work
%%% Under the following conditions:
%%%   * You must attribute the work by retaining this header information
%%%     crediting the original authors and linking to the original
%%%     manuscript.
%%%   * For any reuse or distribution, you must make clear to others the 
%%%     license terms of this work.
%%%   * Any of the above conditions can be waived if you get permission 
%%%     from the copyright holder.
%%%   * Nothing in this license impairs or restricts the author's 
%%%     moral rights.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global houseRules
global playerMoves
global thorp basic

% Unpack structs for faster code
fields = fieldnames(houseRules);
for ii = 1:length(fields)
  name = fields{ii};
  eval([name '= houseRules.' name ';']);
end	
fields = fieldnames(playerMoves);
for ii = 1:length(fields)
  name = fields{ii};
  eval([name '= playerMoves.' name ';']);
end	

if (strcmp(type,'basic'))
  % Basic strategy
  
  strategy.bet = 1;
  
  if (DASA)
    strategy.PAIR = basic.pairStrategyDASA;
  else
    strategy.PAIR = basic.pairStrategyNoDAS;
  end
  
  strategy.HARD = basic.hardStrategy;
  strategy.SOFT = basic.softStrategy;
  
  bet = 1;
  
elseif (strcmp(type,'thorp'))
  % Thorp's Complete Point-Count System
  
  fields = fieldnames(thorp);
  for ii = 1:length(fields)
    name = fields{ii};
    eval([name '= thorp.' name ';']);
  end	
  
  bet = floor(HLI/2);
  bet = max(bet,1);
  bet = min(bet,5);
  strategy.bet = bet;
  
  HARD = zeros(18,10);
  SOFT = zeros(10,10);
  PAIR = zeros(10,10);
  
  for pNum = 4:21
    pIndex = pNum-3;
    for dCard = 2:11
      dIndex = dCard-1;
      if (HLI > hardDouble(pIndex,dIndex))
	HARD(pIndex,dIndex) = DB;
      elseif (HLI > hardDrawStand(pIndex,dIndex))
	HARD(pIndex,dIndex) = S;
      else
	HARD(pIndex,dIndex) = H;
      end
    end
  end
  
  for pNum = 12:21
    pIndex = pNum-11;
    for dCard = 2:11
      dIndex = dCard-1;
      if (HLI > softDouble(pIndex,dIndex))
	SOFT(pIndex,dIndex) = DB;
      elseif (HLI > softDrawStand(pIndex,dIndex))
	SOFT(pIndex,dIndex) = S;
      else
	SOFT(pIndex,dIndex) = H;
      end
    end
  end
  if ((HLI>=1) & (HLI<=10))
    SOFT(17-11,2-1) = DB;
  end
  
  for pNum = 2:11
    pIndex = pNum-1;
    if (pNum < 11)
      PAIR(pIndex,:) = HARD(2*pNum-3,:);
    else
      PAIR(pIndex,:) = SOFT(1,:);
    end
    for dCard = 2:11
      dIndex = dCard-1;
      if (HLI > pairSplit(pIndex,dIndex))
	PAIR(pIndex,dIndex) = SP;
      end
    end
  end
  if (HLI < 24)
    PAIR(2*8-1,10-1) = SP;
  end
  if ((HLI > 5) & ~DASA)
    PAIR(2*4-1,6-1) = SP;
  end
  if ((HLI > 6) | (HLI < -2))
    PAIR(2*3-1,8-1) = SP;
  end
  
  strategy.PAIR = PAIR;
  strategy.SOFT = SOFT;
  strategy.HARD = HARD;

  bet = floor(HLI/2);
  bet = max(bet,1);
  bet = min(bet,5);

else
  fprintf('Unknown type!\n');
  return;
end

